## START: Set by rpmautospec
## (rpmautospec version 0.6.0)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 2;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

# XXX: note for maintainers
# Do NOT update HDMF without checking if packages that depend on it, for
# example python-pynwb can be installed with the new version

%bcond tests 1

# Not yet packaged:
#   https://pypi.org/project/linkml-runtime/
#   https://pypi.org/project/schemasheets/
#   https://pypi.org/project/oaklib/
%bcond termset 0

%global desc %{expand:
The Hierarchical Data Modeling Framework, or *HDMF* is a Python package
for working with hierarchical data. It provides APIs for specifying
data models, reading and writing data to different storage backends,
and representing data with Python object.

Documentation of HDMF can be found at https://hdmf.readthedocs.io}

# We have unbundled hdmf-common-schema. It’s possible that some version skew
# could be tolerated here, but it’s best if the unbundled version can match the
# version that was bundled in the current python-hdmf release. That version
# number can be read from
# src/hdmf/common/hdmf-common-schema/common/namespace.yaml, in
# ['namespaces'][0]['version'].
%global schema_version 1.8.0

Name:           python-hdmf
Version:        3.14.0
Release:        %autorelease
Summary:        A package for standardizing hierarchical object data

License:        BSD-3-Clause-LBNL
URL:            https://github.com/hdmf-dev/hdmf
Source0:        %{url}/releases/download/%{version}/hdmf-%{version}.tar.gz
# Man page hand-written for Fedora in groff_man(7) format based on help output
Source1:        validate_hdmf_spec.1
# Workaround for regression in pytest
# https://github.com/pytest-dev/pytest/issues/12275#issuecomment-2096751244
# https://bugzilla.redhat.com/show_bug.cgi?id=2279858
# https://github.com/hdmf-dev/hdmf/issues/1114
Patch:          pytest.patch

BuildArch:      noarch

BuildRequires:  python3-devel
%if %{with tests}
BuildRequires:  python3dist(pytest)
# Enables an optional integration test with this library:
BuildRequires:  python3dist(tqdm)
%endif

%description %{desc}

%package -n python3-hdmf
Summary:        %{summary}

# Unbundled
%global schema_epoch 1
BuildRequires:  hdmf-common-schema = %{schema_epoch}:%{schema_version}
Requires:       hdmf-common-schema = %{schema_epoch}:%{schema_version}

%description -n python3-hdmf %{desc}

%pyproject_extras_subpkg -n python3-hdmf zarr tqdm %{?with_termset:termset}

# https://docs.fedoraproject.org/en-US/packaging-guidelines/Directory_Replacement/#_scriptlet_to_replace_a_directory
%pretrans -p <lua> -n python3-hdmf
path = "%{python3_sitelib}/hdmf/common/hdmf-common-schema"
st = posix.stat(path)
if st and st.type == "directory" then
  status = os.rename(path, path .. ".rpmmoved")
  if not status then
    suffix = 0
    while not status do
      suffix = suffix + 1
      status = os.rename(path .. ".rpmmoved", path .. ".rpmmoved." .. suffix)
    end
    os.rename(path, path .. ".rpmmoved")
  end
end

%prep
%autosetup -n hdmf-%{version} -p1
rm -vrf src/hdmf/common/hdmf-common-schema/

%generate_buildrequires
%pyproject_buildrequires -x zarr,tqdm%{?with_termset:,termset}

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files hdmf

ln -s %{_datadir}/hdmf-common-schema/ \
    %{buildroot}%{python3_sitelib}/hdmf/common/hdmf-common-schema

install -t '%{buildroot}%{_mandir}/man1' -D -p -m 0644 '%{SOURCE1}'

%check
%if %{with tests}
%pytest -v
%endif

%files -n python3-hdmf -f %{pyproject_files}
%license license.txt
%doc README.rst Legal.txt

%{_bindir}/validate_hdmf_spec
%{_mandir}/man1/validate_hdmf_spec.1*

# symbolic link
%{python3_sitelib}/hdmf/common/hdmf-common-schema

# https://docs.fedoraproject.org/en-US/packaging-guidelines/Directory_Replacement/#_scriptlet_to_replace_a_directory
%ghost %{python3_sitelib}/hdmf/common/hdmf-common-schema.rpmmoved

%changelog
## START: Generated by rpmautospec
* Wed May 29 2024 Sandro <devel@penguinpee.nl> - 3.14.0-2
- Use workaround for regression in pytest 8.2.x
- Close RHBZ#2279858

* Wed May 29 2024 Sandro <devel@penguinpee.nl> - 3.14.0-1
- Update to 3.14.0 (RHBZ#2282478)
- Drop patch (no longer required)

* Sat May 04 2024 Sandro <devel@penguinpee.nl> - 3.13.0-1
- Update to 3.13.0 (RHBZ#2258902)

* Sun Feb 18 2024 Benjamin A. Beasley <code@musicinmybrain.net> - 3.12.2-1
- Update to 3.12.2 (close RHBZ#2258902)

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 3.11.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 3.11.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Nov 03 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.11.0-1
- Update to 3.11.0 (close RHBZ#2247362)

* Thu Oct 05 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.10.0-1
- Update to 3.10.0 (close RHBZ#2241592)

* Wed Aug 23 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.9.0-1
- Update to 3.9.0 (close RHBZ#2232817)

* Thu Aug 10 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.8.1-1
- Update to 3.8.1 (close RHBZ#2224731)

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 3.7.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Thu Jul 13 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.7.0-1
- Update to 3.7.0 (close RHBZ#2222162)
- Now requires hdmf-common-schema 1.7.0
- New “tqdm” extra
- New “linkml” extra omitted (python-linkml-runtime not packaged)

* Wed Jul 12 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.6.1-7
- Fix a test for Python 3.12 (fix RHBZ#2220270)

* Wed Jul 12 2023 Python Maint <python-maint@redhat.com> - 3.6.1-6
- Rebuilt for Python 3.12

* Tue Jul 04 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.6.1-5
- Revert "Use hdmf-common-schema 1.7.0 (close RHBZ#2219455)"

* Tue Jul 04 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.6.1-4
- Use hdmf-common-schema 1.7.0 (close RHBZ#2219455)

* Sat Jun 03 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.6.1-3
- Add pretrans scriptlet for hdmf-common-schema unbundling

* Mon May 22 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.6.1-2
- Unbundle hdmf-common-schema

* Fri May 19 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.6.1-1
- Update to 3.6.1 (close RHBZ#2208458)

* Mon May 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.6.0-1
- Update to 3.6.0 (close RHBZ#2203371)
- Add python3-hdmf+zarr extras metapackage
- Document hdmf-common-schema bundling

* Sat Apr 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.5.5-1
- Update to 3.5.5 (close RHBZ#2178497)

* Fri Feb 17 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 3.5.1-1
- Update to 3.5.1 (close RHBZ#2162209)

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 3.4.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Mon Nov 14 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.4.7-1
- Update to 3.4.7 (close RHBZ#2142083)

* Wed Oct 05 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.4.6-1
- Update to 3.4.6 (close RHBZ#2132203)

* Wed Oct 05 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.4.5-2
- Update License to SPDX

* Thu Sep 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.4.5-1
- Update to 3.4.5 (close RHBZ#2128676)

* Thu Sep 15 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.4.3-1
- Update to 3.4.3 (close RHBZ#2115971)

* Thu Sep 15 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.3.2-8
- Remove obsolete patches

* Mon Sep 12 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.3.2-7
- Add a man page

* Mon Sep 12 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.3.2-6
- Use pytest as the test runner

* Mon Sep 12 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.3.2-5
- Remove all upper bounds (but no lower bounds) from setup.py

* Mon Sep 12 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.3.2-4
- Don’t use requirements.txt

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 3.3.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Tue Jun 28 2022 Luis Bazan <lbazan@fedoraproject.org> - 3.3.2-2
- the new version cover the patch.

* Tue Jun 28 2022 Luis Bazan <lbazan@fedoraproject.org> - 3.3.2-1
- new upstream version

* Sun Jun 26 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 3.1.1-8
- Fix test failures on Python 3.11 (fix RHBZ#2098968)
- Updated patch for upstream bug#663 (backported PR#664)
- Backported PR#689

* Wed Jun 15 2022 Python Maint <python-maint@redhat.com> - 3.1.1-7
- Rebuilt for Python 3.11

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 3.1.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sun Jan 16 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 3.1.1-5
- feat: fix FTI

* Mon Oct 18 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 3.1.1-2
- Drop unnecessary python_enable_dependency_generator macro
- Drop unnecessary python-flake8 BR (work around RHBZ#2014589)

* Mon Aug 16 2021 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 3.1.1-1
- Update to latest release
- Enable tests

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Fri Jun 04 2021 Python Maint <python-maint@redhat.com> - 2.4.0-3
- Rebuilt for Python 3.10

* Sun Apr 11 2021 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.4.0-2
- Add maintainer note
- Report failing tests upstream and add comment

* Wed Apr 07 2021 Luis Bazan <lbazan@fedoraproject.org> - 2.4.0-1
- New upstream

* Wed Jan 27 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Sat Aug 22 2020 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 2.1.0-1
- Update to 2.1.0

* Sat Aug 08 2020 Luis Bazan <lbazan@fedoraproject.org> - 2.0.1-1
- New upstream version

* Wed Jul 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Wed Jun 03 2020 Luis Bazan <lbazan@fedoraproject.org> - 1.6.2-1
- New upstream version

* Tue May 26 2020 Miro Hrončok <mhroncok@redhat.com> - 1.6.1-2
- Rebuilt for Python 3.9

* Tue Mar 03 2020 Luis Bazan <lbazan@fedoraproject.org> - 1.6.1-1
- New upstream version

* Fri Feb 28 2020 Luis Bazan <lbazan@fedoraproject.org> - 1.6.0-1
- New upstream version

* Thu Jan 30 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.5.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Jan 27 2020 Luis Bazan <lbazan@fedoraproject.org> - 1.5.4-1
- New upstream version

* Wed Jan 08 2020 Luis Bazan <lbazan@fedoraproject.org> - 1.5.1-2
- Rebuild with other source

* Wed Jan 08 2020 Luis Bazan <lbazan@fedoraproject.org> - 1.5.1-1
- New upstream version

* Wed Jan 08 2020 Luis Bazan <lbazan@fedoraproject.org> - 1.5.0-1
- New upstream version

* Thu Dec 19 2019 Aniket Pradhan <major AT fedoraproject DOT org> - 1.4.0-1
- Update to v1.4.0
- Use bundled source along with the schema files
- https://github.com/hdmf-dev/hdmf/issues/195
- Use Legal.txt as a separate source as it is not included in the source tar 
- Remove unnecessary requirements

* Mon Nov 11 2019 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 1.3.3-4
- Remove unneeded configparser BR
- https://bugzilla.redhat.com/show_bug.cgi?id=1770629
- Fix failing tests
- Include required schema files
- Re-order BRs alphabetically

* Thu Nov 07 2019 Luis Bazan <lbazan@fedoraproject.org> - 1.3.3-3
- fix source

* Thu Nov 07 2019 Luis Bazan <lbazan@fedoraproject.org> - 1.3.3-2
- remove legal from doc

* Thu Nov 07 2019 Luis Bazan <lbazan@fedoraproject.org> - 1.3.3-1
- New upstream version

* Thu Oct 03 2019 Luis Bazan <lbazan@fedoraproject.org> - 1.3.2-2
- Rebuild with new source

* Thu Oct 03 2019 Luis Bazan <lbazan@fedoraproject.org> - 1.3.2-1
- New upstream version

* Thu Oct 03 2019 Miro Hrončok <mhroncok@redhat.com> - 1.2.0-2
- Rebuilt for Python 3.8.0rc1 (#1748018)

* Sat Aug 31 2019 Luis Bazan <lbazan@fedoraproject.org> - 1.2.0-1
- New upstream version

* Mon Aug 19 2019 Miro Hrončok <mhroncok@redhat.com> - 1.1.2-2
- Rebuilt for Python 3.8

* Fri Aug 16 2019 Luis Bazan <lbazan@fedoraproject.org> - 1.1.2-1
- New upstream version

* Fri Jul 26 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.0.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Tue Jul 02 2019 Luis Bazan <lbazan@fedoraproject.org> - 1.0.5-1
- New upstream version

* Wed Jun 26 2019 Luis Bazan <lbazan@fedoraproject.org> - 1.0.4-2
- Fix some typos

* Wed Jun 26 2019 Luis Bazan <lbazan@fedoraproject.org> - 1.0.4-1
- New upstream version

* Tue Jun 11 2019 Luis Bazan <lbazan@fedoraproject.org> - 1.0.3-2
- Fix BR typo

* Mon Apr 29 2019 Luis Bazan <lbazan@fedoraproject.org> - 1.0.3-1
- New upstream version

* Sun Apr 21 2019 Luis Bazan <lbazan@fedoraproject.org> - 1.0.2-1
- New upstream version

* Tue Mar 26 2019 Luis Bazan <lbazan@fedoraproject.org> - 1.0.1-1
- Initial package.


## END: Generated by rpmautospec
